==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/eo.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Bildaro",
    "Could not move \"{file}\", target exists" : "Ne eblas movi “{file}”-n, celo jam ekzistas",
    "Could not move \"{file}\"" : "Ne eblas movi “{file}”-n",
    "Could not load the description: " : "Ne ŝargeblis la priskribo:",
    "Copyright" : "Kopirajto",
    "New" : "Nova",
    "Error loading slideshow template" : "Eraro dum ŝargado de ŝablono pri lumbilda prezento",
    "Next" : "Sekva",
    "Play" : "Ludi",
    "Pause" : "Paŭzigi",
    "Previous" : "Antaŭa",
    "Close" : "Fermi",
    "Download" : "Elŝuti",
    "Delete" : "Forigi",
    "Share" : "Kunhavigi",
    "Could not create file \"{file}\" because it already exists" : "Ne eblas krei dosieron “{file}” ĉar ĝi jam ekzistas",
    "Could not create file \"{file}\"" : "Ne eblas krei dosieron “{file}”",
    "\"{name}\" is an invalid file name." : "“{name}” estas nevalida dosiernomo.",
    "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
    "Upload" : "Alŝuti",
    "Error" : "Eraro",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Error while unsharing" : "Eraro dum malkunhavigo",
    "Error while changing permissions" : "Eraro dum ŝanĝo de permesoj",
    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
    "Share with users or groups …" : "Kunhavigi kun uzantoj aŭ grupoj.",
    "Share with users, groups or remote users …" : "Kunhavigi kun uzantoj, grupoj aŭ foraj uzantoj...",
    "Share link" : "Kunhavigi ligilon",
    "The public link will expire no later than {days} days after it is created" : "La publika ligilo senvalidiĝos ne pli malfrue ol {days} tagojn post ĝi kreiĝos",
    "Link" : "Ligilo",
    "Password protect" : "Protekti per pasvorto",
    "Password" : "Pasvorto",
    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
    "Allow editing" : "Permesi redakton",
    "Email link to person" : "Retpoŝti la ligilon al ulo",
    "Send" : "Sendi",
    "Set expiration date" : "Agordi limdaton",
    "Expiration" : "Eksvalidiĝo",
    "Expiration date" : "Limdato",
    "An error occured. Please try again" : "Eraro okazis, Bonvolu provi ree.",
    "Adding user..." : "Aldonante uzanton...",
    "group" : "grupo",
    "remote" : "fora",
    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
    "Unshare" : "Malkunhavigi",
    "notify by email" : "avizi per retpoŝto",
    "can share" : "kunhavebla",
    "can edit" : "povas redakti",
    "access control" : "alirkontrolo",
    "create" : "krei",
    "change" : "ŝanĝi",
    "delete" : "forigi",
    "Password protected" : "Protektita per pasvorto",
    "Error unsetting expiration date" : "Eraro dum malagordado de limdato",
    "Error setting expiration date" : "Eraro dum agordado de limdato",
    "Sending ..." : "Sendante...",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Warning" : "Averto",
    "This share is password-protected" : "Ĉi tiu kunhavigo estas protektata per pasvorto",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Cancel upload" : "Nuligi alŝuton",
    "File list" : "Listo de dosieroj",
    "Reasons might be:" : "Kialoj povas esti:",
    "the item was removed" : "la ero foriĝis",
    "sharing is disabled" : "kunhavigo malkapablas",
    "Picture view" : "Bilda vido",
    "Gallery view" : "Galeria vido"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/eo.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Bildaro",
    "Could not move \"{file}\", target exists" : "Ne eblas movi “{file}”-n, celo jam ekzistas",
    "Could not move \"{file}\"" : "Ne eblas movi “{file}”-n",
    "Could not load the description: " : "Ne ŝargeblis la priskribo:",
    "Copyright" : "Kopirajto",
    "New" : "Nova",
    "Error loading slideshow template" : "Eraro dum ŝargado de ŝablono pri lumbilda prezento",
    "Next" : "Sekva",
    "Play" : "Ludi",
    "Pause" : "Paŭzigi",
    "Previous" : "Antaŭa",
    "Close" : "Fermi",
    "Download" : "Elŝuti",
    "Delete" : "Forigi",
    "Share" : "Kunhavigi",
    "Could not create file \"{file}\" because it already exists" : "Ne eblas krei dosieron “{file}” ĉar ĝi jam ekzistas",
    "Could not create file \"{file}\"" : "Ne eblas krei dosieron “{file}”",
    "\"{name}\" is an invalid file name." : "“{name}” estas nevalida dosiernomo.",
    "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
    "Upload" : "Alŝuti",
    "Error" : "Eraro",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Error while unsharing" : "Eraro dum malkunhavigo",
    "Error while changing permissions" : "Eraro dum ŝanĝo de permesoj",
    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
    "Share with users or groups …" : "Kunhavigi kun uzantoj aŭ grupoj.",
    "Share with users, groups or remote users …" : "Kunhavigi kun uzantoj, grupoj aŭ foraj uzantoj...",
    "Share link" : "Kunhavigi ligilon",
    "The public link will expire no later than {days} days after it is created" : "La publika ligilo senvalidiĝos ne pli malfrue ol {days} tagojn post ĝi kreiĝos",
    "Link" : "Ligilo",
    "Password protect" : "Protekti per pasvorto",
    "Password" : "Pasvorto",
    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
    "Allow editing" : "Permesi redakton",
    "Email link to person" : "Retpoŝti la ligilon al ulo",
    "Send" : "Sendi",
    "Set expiration date" : "Agordi limdaton",
    "Expiration" : "Eksvalidiĝo",
    "Expiration date" : "Limdato",
    "Adding user..." : "Aldonante uzanton...",
    "group" : "grupo",
    "remote" : "fora",
    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
    "Unshare" : "Malkunhavigi",
    "notify by email" : "avizi per retpoŝto",
    "can share" : "kunhavebla",
    "can edit" : "povas redakti",
    "access control" : "alirkontrolo",
    "create" : "krei",
    "change" : "ŝanĝi",
    "delete" : "forigi",
    "Password protected" : "Protektita per pasvorto",
    "Error unsetting expiration date" : "Eraro dum malagordado de limdato",
    "Error setting expiration date" : "Eraro dum agordado de limdato",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Warning" : "Averto",
    "This share is password-protected" : "Ĉi tiu kunhavigo estas protektata per pasvorto",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Cancel upload" : "Nuligi alŝuton",
    "File list" : "Listo de dosieroj",
    "Reasons might be:" : "Kialoj povas esti:",
    "the item was removed" : "la ero foriĝis",
    "sharing is disabled" : "kunhavigo malkapablas",
    "Picture view" : "Bilda vido",
    "Gallery view" : "Galeria vido",
    "An error occured. Please try again" : "Eraro okazis, Bonvolu provi ree.",
    "Sending ..." : "Sendante..."
},
"nplurals=2; plural=(n != 1);");
